package com.dcs.hnyz.service;

import java.util.List;

import com.dcs.common.core.page.TableDataInfo;
import com.dcs.hnyz.domain.PipelineInstance;
import com.dcs.hnyz.domain.vo.PipeLineInstanceFormVO;

/**
 * 管道实例管理Service接口
 * 
 * @author hmy
 * @date 2025-07-04
 */
public interface IPipelineInstanceService 
{
    /**
     * 查询管道实例管理
     * 
     * @param id 管道实例管理主键
     * @return 管道实例管理
     */
    public PipelineInstance selectPipelineInstanceById(Long id);

    /**
     * 查询管道实例管理列表
     * 
     * @param pipelineInstance 管道实例管理
     * @return 管道实例管理集合
     */
    public List<PipeLineInstanceFormVO> selectPipelineInstanceList(PipelineInstance pipelineInstance);

    /**
     * 新增管道实例管理
     * 
     * @param pipelineInstance 管道实例管理
     * @return 结果
     */
    public int insertPipelineInstance(PipelineInstance pipelineInstance);

    /**
     * 修改管道实例管理
     * 
     * @param pipelineInstance 管道实例管理
     * @return 结果
     */
    public int updatePipelineInstance(PipelineInstance pipelineInstance);

    /**
     * 批量删除管道实例管理
     * 
     * @param ids 需要删除的管道实例管理主键集合
     * @return 结果
     */
    public int deletePipelineInstanceByIds(Long[] ids);

    /**
     * 删除管道实例管理信息
     * 
     * @param id 管道实例管理主键
     * @return 结果
     */
    public int deletePipelineInstanceById(Long id);

    /**
     * 根据流程id查询管道实例列表
     * @param pageId
     * @return
     */
    List<PipelineInstance> getListByPageId(Long pageId);
}
